from setuptools import setup

setup(name='probability_distributions_q4l',
      version='2',
      description='Gaussian distributions',
      packages=['probability_distributions_q4l'],
      zip_safe=False)
